@@ -18,6 +18,7 @@
 #include <ksimpleconfig.h>
 #include <kdeversion.h>
 #include <kmessagebox.h>
+#include <kiconloader.h>
 
 #include <qfile.h>
 #include <qtextcodec.h>
@@ -27,6 +28,8 @@
 #include <qheader.h>
 #include <qclipboard.h>
 #include <qmessagebox.h>
+#include <qtoolbutton.h>
+#include <qcombobox.h>
 
 #include "bbsview.h"
 
@@ -80,6 +83,9 @@ KitaBBSView::KitaBBSView( QWidget *parent, const char *name )
                                const KURL&, const KParts::URLArgs&, QString, int, const KURL& ) ),
              signalCollection, SIGNAL( openURLRequestExt(
                                            const KURL& , const KParts::URLArgs&, QString, int, const KURL& ) ) );
+
+    connect( SearchCombo, SIGNAL( textChanged( const QString& ) ),
+             SLOT( filter( const QString& ) ) );
 }
 
 KitaBBSView::~KitaBBSView()
@@ -495,6 +501,7 @@ void KitaBBSView::loadBoard( QListViewItem* item )
 void KitaBBSView::setFont( const QFont& font )
 {
     m_boardList->setFont( font );
+    SearchCombo->setFont( font );
 }
 
 /* public slot :*/ /* virtual */
@@ -622,3 +629,30 @@ void KitaBBSView::saveOpened()
 
     config.writeEntry( "Opened", openedList );
 }
+
+/**
+ * search and show matched item.
+ *
+ * @param str string to search.
+ */
+void KitaBBSView::filter( const QString& str )
+{
+    QListViewItem* categoryItem;
+    QListViewItem* boardItem;
+
+    for ( categoryItem = m_boardList->firstChild(); categoryItem; categoryItem = categoryItem->nextSibling() ) {
+        bool matched = false;
+
+        for ( boardItem = categoryItem->firstChild(); boardItem; boardItem = boardItem->nextSibling() ) {
+            QString boardName = boardItem->text( 0 );
+            if ( boardName.contains( str ) ) {
+                boardItem->setVisible( true );
+                matched = true;
+            } else {
+                boardItem->setVisible( false );
+            }
+        }
+
+        categoryItem->setVisible( matched );
+    }    
+}
