@@ -24,7 +24,7 @@
 #include <qclipboard.h>
 
 
-KitaSubjectTabWidget::KitaSubjectTabWidget( QWidget* parent, const char* name, WFlags f )
+KitaBoardTabWidget::KitaBoardTabWidget( QWidget* parent, const char* name, WFlags f )
         : KitaTabWidgetBase( parent, name, f )
 {
     setXMLFile( "boardtabwidgetui.rc" );
@@ -37,11 +37,11 @@ KitaSubjectTabWidget::KitaSubjectTabWidget( QWidget* parent, const char* name, W
     setupActions();
 }
 
-KitaSubjectTabWidget::~KitaSubjectTabWidget()
+KitaBoardTabWidget::~KitaBoardTabWidget()
 {}
 
 /* public slots */
-void KitaSubjectTabWidget::loadBoard( const KURL& boardURL, bool withNewTab )
+void KitaBoardTabWidget::loadBoard( const KURL& boardURL, bool withNewTab )
 {
     KitaBoardView * view = findView( boardURL );
     QString boardName = Kita::BoardManager::boardName( boardURL );
@@ -67,7 +67,7 @@ void KitaSubjectTabWidget::loadBoard( const KURL& boardURL, bool withNewTab )
 }
 
 /* create KitaBoardView */ /* private */
-KitaBoardView* KitaSubjectTabWidget::createView( QString label )
+KitaBoardView* KitaBoardTabWidget::createView( QString label )
 {
     KitaBoardView * view = new KitaBoardView( this );
     if ( view ) {
@@ -79,7 +79,7 @@ KitaBoardView* KitaSubjectTabWidget::createView( QString label )
 }
 
 /* private */
-KitaBoardView* KitaSubjectTabWidget::findView( const KURL& boardURL )
+KitaBoardView* KitaBoardTabWidget::findView( const KURL& boardURL )
 {
     int max = count() - 1;
     if ( max <= 0 ) return NULL;
@@ -96,7 +96,7 @@ KitaBoardView* KitaSubjectTabWidget::findView( const KURL& boardURL )
 
 
 /* protected */ /* virtual */
-void KitaSubjectTabWidget::deleteWidget( QWidget* w )
+void KitaBoardTabWidget::deleteWidget( QWidget* w )
 {
     KitaBoardView * view = isSubjectView( w );
     if ( !view ) return ;
@@ -106,7 +106,7 @@ void KitaSubjectTabWidget::deleteWidget( QWidget* w )
 
 
 /* private */
-KitaBoardView* KitaSubjectTabWidget::isSubjectView( QWidget* w )
+KitaBoardView* KitaBoardTabWidget::isSubjectView( QWidget* w )
 {
     KitaBoardView * view = NULL;
     if ( w ) {
@@ -120,7 +120,7 @@ KitaBoardView* KitaSubjectTabWidget::isSubjectView( QWidget* w )
 /* KitaBoardView actions */
 
 /* private */
-void KitaSubjectTabWidget::setupActions()
+void KitaBoardTabWidget::setupActions()
 {
     new KAction( i18n( "Find" ),
                  "find",
@@ -161,21 +161,21 @@ void KitaSubjectTabWidget::setupActions()
 }
 
 /* public slot */
-void KitaSubjectTabWidget::slotReloadButton()
+void KitaBoardTabWidget::slotReloadButton()
 {
     KitaBoardView * view = isSubjectView( currentPage() );
     if ( view ) view->reloadSubject();
 }
 
 /* public slot */
-void KitaSubjectTabWidget::slotFocusSearchCombo()
+void KitaBoardTabWidget::slotFocusSearchCombo()
 {
     KitaBoardView * view = isSubjectView( currentPage() );
     if ( view ) view->slotFocusSearchCombo();
 }
 
 /* public slot */
-void KitaSubjectTabWidget::slotNewThread()
+void KitaBoardTabWidget::slotNewThread()
 {
     KitaBoardView * view = isSubjectView( currentPage() );
     if ( view ) view->slotCreateNewThread();
@@ -183,7 +183,7 @@ void KitaSubjectTabWidget::slotNewThread()
 
 
 /* public slot */
-void KitaSubjectTabWidget::slotShowOldLogs( int idx )
+void KitaBoardTabWidget::slotShowOldLogs( int idx )
 {
     KitaBoardView * view;
     if ( idx == -1 ) view = isSubjectView( currentPage() );
@@ -192,7 +192,7 @@ void KitaSubjectTabWidget::slotShowOldLogs( int idx )
 }
 
 /* public slot */
-void KitaSubjectTabWidget::slotShowTitleImg( int idx )
+void KitaBoardTabWidget::slotShowTitleImg( int idx )
 {
     KitaBoardView * view;
     if ( idx == -1 ) view = isSubjectView( currentPage() );
@@ -200,7 +200,7 @@ void KitaSubjectTabWidget::slotShowTitleImg( int idx )
     if ( view ) {
         KURL imgURL = Kita::BoardManager::titleImgURL( view->boardURL() );
         if ( !imgURL.isEmpty() ) {
-            emit openURLRequestExt( imgURL, KParts::URLArgs(), QString::null, 1, 0, view->boardURL() );
+            emit openURLRequestExt( imgURL, KParts::URLArgs(), QString::null, 1, view->boardURL() );
         }
     }
 }
@@ -234,7 +234,7 @@ void SubjectTabBar::showPopupMenu( int idx, QPoint global )
         MENU_SHOWOLDLOGS
     };
 
-    KitaSubjectTabWidget* tabwidget = static_cast<KitaSubjectTabWidget*>( parentWidget() );
+    KitaBoardTabWidget* tabwidget = static_cast<KitaBoardTabWidget*>( parentWidget() );
     KActionCollection * collection = tabwidget->actionCollection();
 
     if ( QString::compare( tabwidget->page( idx ) ->name(), "favoriteTab" ) == 0 ) return ;
@@ -292,7 +292,7 @@ void SubjectTabBar::showPopupMenu( int idx, QPoint global )
 /*--------------------------------------------------------------*/
 
 
-KitaSubjectDock::KitaSubjectDock( KDockManager* dockManager,
+KitaBoardDock::KitaBoardDock( KDockManager* dockManager,
                                   const char* name,
                                   const QPixmap &pixmap,
                                   QWidget* parent,
@@ -302,30 +302,30 @@ KitaSubjectDock::KitaSubjectDock( KDockManager* dockManager,
     : KitaDockWidgetBase( dockManager, name, pixmap, parent, strCaption, strTabPageLabel, f ) {}
 
 
-KitaSubjectDock::~KitaSubjectDock()
+KitaBoardDock::~KitaBoardDock()
 {
-    if ( m_subjectTab ) delete m_subjectTab;
+    if ( m_boardTab ) delete m_boardTab;
 }
 
 
-/* setup & create KitaSubjectDock */ /* public */
-KitaSubjectTabWidget* KitaSubjectDock::setup()
+/* setup & create KitaBoardDock */ /* public */
+KitaBoardTabWidget* KitaBoardDock::setup()
 {
     /* create KitaNaviTabWidget */
-    m_subjectTab = new KitaSubjectTabWidget( this, "Subject" );
-    setWidget( m_subjectTab );
+    m_boardTab = new KitaBoardTabWidget( this, "Subject" );
+    setWidget( m_boardTab );
 
     Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
     connect( signalCollection, SIGNAL( switchToSubject() ),
              SLOT( slotShowDock() ) );
 
-    return m_subjectTab;
+    return m_boardTab;
 }
 
 /* public slot */
-void KitaSubjectDock::slotLoadBoard( const KURL& boardURL, bool withNewTab )
+void KitaBoardDock::slotLoadBoard( const KURL& boardURL, bool withNewTab )
 {
     slotShowDock();
 
-    if ( m_subjectTab ) m_subjectTab->loadBoard( boardURL, withNewTab );
+    if ( m_boardTab ) m_boardTab->loadBoard( boardURL, withNewTab );
 }
