@@ -259,11 +259,11 @@ void KitaTabWidgetBase::connectSignals()
              signalCollection, SIGNAL( setMainCaption( const QString& ) ) );
 
     connect( this, SIGNAL( openURLRequestExt(
-                               const KURL&, const KParts::URLArgs&, QString, int, int,
-                               const KURL&, const KURL&, const QString&, const QString& ) ),
+                               const KURL&, const KParts::URLArgs&, QString, int,
+                               const KURL& ) ),
              signalCollection, SIGNAL( openURLRequestExt(
-                                           const KURL& , const KParts::URLArgs&, QString, int, int,
-                                           const KURL&, const KURL&, const QString&, const QString& ) ) );
+                                           const KURL& , const KParts::URLArgs&, QString, int,
+                                           const KURL& ) ) );
 }
 
 
