@@ -34,7 +34,7 @@ namespace Kita
         Access( const KURL& datURL );
         virtual ~Access() {};
 
-	void init();
+        void init();
         QString get();
         void killJob();
         void stopJob();
@@ -42,10 +42,12 @@ namespace Kita
         void getcache();
         bool getupdate( int readNum );
         int responseCode();
+        const int dataSize() const;
+        const bool invalidDataReceived() const;
 
     protected:
         void writeCacheData();
-        void emitDatLineList( const QString& dataStream );	
+        void emitDatLineList( const QString& dataStream );
 
         const KURL m_datURL;
         KIO::Job* m_currentJob;
@@ -54,7 +56,7 @@ namespace Kita
         int m_dataSize;
         bool m_firstReceive;
         bool m_invalidDataReceived;
-        int m_bbstype;	
+        int m_bbstype;
         int m_readNum;
         QString m_lastLine;
 
