@@ -477,7 +477,19 @@ int DatInfo::getHTML( int num, bool checkAbone, QString& titleHTML, QString& bod
     return getHTMLPrivate( num, checkAbone, titleHTML, bodyHTML );
 }
 
-/* private */
+/**
+ * @param[in] num
+ * @param[in] checkAbone
+ *
+ * @param[out] titleHTML
+ * @param[out] bodyHTML
+ *
+ * @retval KITA_HTML_NOTPARSED The dat is not parsed.
+ * @retval KITA_HTML_ABONE The res dat is marked as abone.
+ * @retval KITA_HTML_BROKEN The res dat is marked as broken.
+ * @retval KITA_HTML_NORMAL The res dat is normal.
+ *
+ */
 int DatInfo::getHTMLPrivate( int num, bool checkAbone, QString& titleHTML, QString& bodyHTML )
 {
     if ( !parseDat( num ) ) return KITA_HTML_NOTPARSED;
@@ -485,34 +497,25 @@ int DatInfo::getHTMLPrivate( int num, bool checkAbone, QString& titleHTML, QStri
     bool abone = checkAbone & checkAbonePrivate( num );
     RESDAT& resdat = m_resDatVec[ num ];
 
-    if ( !resdat.broken && !abone ) {
+    if ( abone ) {
+        titleHTML = QString().setNum( num ) + " " + i18n( "Abone" );
+        bodyHTML = "<a href=\"#abone" + QString().setNum( num ) + "\">";
+        bodyHTML += i18n( "Abone" ) + "</a>";
 
+        return KITA_HTML_ABONE;
+    } else if ( resdat.broken ) {
+        titleHTML = QString().setNum( num ) + " " + i18n( "Broken" );
+        bodyHTML = i18n( "Broken" );
+
+        return KITA_HTML_BROKEN;
+    } else {
         createTitleHTML( resdat, titleHTML );
         bodyHTML = resdat.bodyHTML;
-    } else {
-
-        /* "abone" */
-        if ( abone ) {
-            titleHTML = QString().setNum( num ) + " " + i18n( "Abone" );
-            bodyHTML = "<a href=\"#abone" + QString().setNum( num ) + "\">";
-            bodyHTML += i18n( "Abone" ) + "</a>";
-
-            return KITA_HTML_ABONE;
-        }
-
-        /* "broken" */
-        else {
-            titleHTML = QString().setNum( num ) + " " + i18n( "Broken" );
-            bodyHTML = i18n( "Broken" );
-
-            return KITA_HTML_BROKEN;
-        }
+        
+        return KITA_HTML_NORMAL;
     }
-
-    return KITA_HTML_NORMAL;
 }
 
-
 /* get HTML strings from startnum to endnum.
  
    return value is HTML strings               */  /* public */
@@ -557,8 +560,16 @@ QString DatInfo::getHtmlByID( const QString& strid, int &count )
     return retHTML;
 }
 
-
-/* private */
+/**
+ *
+ * convert res dat to html.
+ *
+ * @param[in] num
+ * @param[in] checkAbone
+ *
+ * @param[out] html
+ *
+ */
 void DatInfo::getHTMLofOneRes( int num, bool checkAbone, QString& html )
 {
     html = QString::null;
