@@ -73,6 +73,8 @@ struct RESDAT
     QString date;
     QDateTime dateTime;
     QString id;
+    QString be;
+    QString bepointmark;
     QString host;
     QString bodyHTML;
 
