@@ -20,6 +20,19 @@
 #include <qstylesheet.h>
 #include <qdom.h>
 
+// FavoriteThreadItem
+FavoriteThreadItem::FavoriteThreadItem()
+{}
+
+FavoriteThreadItem::~ FavoriteThreadItem()
+{}
+
+bool FavoriteThreadItem::operator==( const FavoriteThreadItem& item ) const
+{
+    return ( m_datURL == item.m_datURL );
+}
+
+// FavoriteThreads
 FavoriteThreads* FavoriteThreads::instance = 0;
 
 FavoriteThreads::FavoriteThreads()
@@ -57,7 +70,7 @@ bool FavoriteThreads::contains( const QString& datURL )
     }
 }
 
-const QValueList<QString> FavoriteThreads::threadList() const
+const QValueList<FavoriteThreadItem> FavoriteThreads::threadList() const
 {
     return m_threadList;
 }
@@ -91,7 +104,7 @@ void FavoriteThreads::processThreadNode( QDomNode& node )
     QDomNode datURLNode = node.namedItem( "daturl" );
     QDomNode nameNode = node.namedItem( "name" );
 
-    if ( !datURLNode.isElement() || !nameNode.isElement() ) return;
+    if ( !datURLNode.isElement() || !nameNode.isElement() ) return ;
 
     QString url = datURLNode.toElement().text();
     QString name = nameNode.toElement().text();
@@ -100,7 +113,7 @@ void FavoriteThreads::processThreadNode( QDomNode& node )
     Kita::Thread* thread = Kita::Thread::getByURL( datURL );
     thread->setThreadName( name );
     Kita::ThreadIndex::loadIndex( thread, datURL );
-    
+
     FavoriteThreads::getInstance() ->insert( datURL.prettyURL() );
 }
 
@@ -114,9 +127,9 @@ const QString FavoriteThreads::toXML() const
     QDomElement root = document.createElementNS( "http://kita.sourceforge.jp/ns/favorites", "favorites" );
     document.appendChild( root );
 
-    QValueList<QString>::const_iterator it;
+    QValueList<FavoriteThreadItem>::const_iterator it;
     for ( it = threadList().begin(); it != threadList().end(); ++it ) {
-        QString datURL = ( *it );
+        QString datURL = ( *it ).m_datURL;
         QDomElement threadElement = document.createElementNS( "http://kita.sourceforge.jp/ns/thread", "thread" );
         root.appendChild( threadElement );
 
@@ -128,24 +141,24 @@ const QString FavoriteThreads::toXML() const
         QDomElement nameElement = document.createElement( "name" );
         threadElement.appendChild( nameElement );
         nameElement.appendChild( document.createTextNode( threadName ) );
-  	 
-        QString resNum = QString::number( Kita::DatManager::getResNum( datURL ) ); 	 
-        QDomElement resNumElement = document.createElement( "resnum" ); 	 
-        threadElement.appendChild( resNumElement ); 	 
-        resNumElement.appendChild( document.createTextNode( resNum ) ); 	 
-  	 
-        // board 	 
-        QDomElement board = document.createElementNS( "http://kita.sourceforge.jp/ns/board", "board" );   
-        threadElement.appendChild( board ); 	 
 
-        QString boardURL = Kita::BoardManager::boardURL( datURL ); 	 
-        QDomElement boardURLElement = document.createElement( "url" ); 	 
-        board.appendChild( boardURLElement ); 	 
-        boardURLElement.appendChild( document.createTextNode( boardURL ) ); 	 
+        QString resNum = QString::number( Kita::DatManager::getResNum( datURL ) );
+        QDomElement resNumElement = document.createElement( "resnum" );
+        threadElement.appendChild( resNumElement );
+        resNumElement.appendChild( document.createTextNode( resNum ) );
 
-        QString boardName = Kita::BoardManager::boardName( boardURL ); 	 
-        QDomElement boardNameElement = document.createElement( "name" ); 	 
-        board.appendChild( boardNameElement ); 	 
+        // board
+        QDomElement board = document.createElementNS( "http://kita.sourceforge.jp/ns/board", "board" );
+        threadElement.appendChild( board );
+
+        QString boardURL = Kita::BoardManager::boardURL( datURL );
+        QDomElement boardURLElement = document.createElement( "url" );
+        board.appendChild( boardURLElement );
+        boardURLElement.appendChild( document.createTextNode( boardURL ) );
+
+        QString boardName = Kita::BoardManager::boardName( boardURL );
+        QDomElement boardNameElement = document.createElement( "name" );
+        board.appendChild( boardNameElement );
         boardNameElement.appendChild( document.createTextNode( boardName ) );
     }
     return document.toString( 0 );
@@ -153,11 +166,11 @@ const QString FavoriteThreads::toXML() const
 
 void FavoriteThreads::replace( QString fromURL, QString toURL )
 {
-    if( FavoriteThreads::getInstance() == NULL ) return;
-    QValueList<QString>& threadList = FavoriteThreads::getInstance() ->m_threadList;
-    QValueList<QString>::iterator it;
+    if ( FavoriteThreads::getInstance() == NULL ) return ;
+    QValueList<FavoriteThreadItem>& threadList = FavoriteThreads::getInstance() ->m_threadList;
+    QValueList<FavoriteThreadItem>::iterator it;
     for ( it = threadList.begin(); it != threadList.end(); ++it ) {
-        QString url = ( *it );
+        QString url = ( *it ).m_datURL;
         if ( url.find( fromURL ) == 0 ) {
             url = url.replace( 0, fromURL.length(), toURL );
             threadList.remove( it );
@@ -166,3 +179,12 @@ void FavoriteThreads::replace( QString fromURL, QString toURL )
         }
     }
 }
+
+QString FavoriteThreads::getDatURL( int i )
+{
+    if ( getInstance() ->m_threadList.count() > i ) {
+        return getInstance() ->m_threadList[ i ].m_datURL;
+    } else {
+        return QString::null;
+    }
+}
