@@ -23,22 +23,36 @@ class QDomNode;
 /**
 @author Hideki Ikemoto
 */
+class FavoriteThreadItem
+{
+public:
+    QString m_datURL;
+    FavoriteThreadItem();
+    FavoriteThreadItem( const QString& datURL ) { m_datURL = datURL; }
+    ~FavoriteThreadItem();
+
+    bool operator==( const FavoriteThreadItem& item ) const;
+};
+
 class FavoriteThreads
 {
     static FavoriteThreads* instance;
-    QValueList<QString> m_threadList;
+    QValueList<FavoriteThreadItem> m_threadList;
     FavoriteThreads();
     ~FavoriteThreads();
+    const QValueList<FavoriteThreadItem> threadList() const;
 public:
     static FavoriteThreads* getInstance();
     void insert( const QString& datURL );
     void remove( const QString& datURL );
     static bool contains( const QString& datURL );
-    const QValueList<QString> threadList() const;
     const QString toXML() const;
     static bool readFromXML( const QString& xml );
     static void processThreadNode( QDomNode& node );
     static void replace( QString fromURL, QString toURL );
+    // FIXME: use Iterator
+    static QString getDatURL( int i );
+static int count() { return getInstance() ->m_threadList.count(); }
 };
 
 #endif
