@@ -18,12 +18,6 @@
 class KURL;
 class QDateTime;
 
-namespace DOM
-{
-    class HTMLDocument;
-    class Element;
-}
-
 struct RESDAT;
 
 
@@ -33,33 +27,25 @@ enum{
     URLMODE_THREAD
 };
 
-
-/* parse mode */
-enum{
-    PARSEMODE_DOM,
-    PARSEMODE_HTML,
-    PARSEMODE_TEXT
-};
-
-
 namespace Kita
 {
     /**
      * @author Hideki Ikemoto
      */
 
-    /*------------------------------*/    
+    /*------------------------------*/
     /* text codecs */
     QString qcpToUnicode( const QString& str );
     QString utf8ToUnicode( const QString& str );
     QString ecuToUnicode( const QString& str );
 
-    
+
     /*------------------------------*/
     /* conversion of DAT  */
-    QString DatToHtml( const QString& rawData, int num, bool showAddr );
-    QString ResDatToHtml( const RESDAT& resdat, int num, bool showAddr );
-    
+    QString DatToHtml( const QString& rawData, int num );
+    void DatToText( const QString &rawData, QString& text );
+    QString parseSpecialChar( const QChar *cdat, unsigned int& pos );
+
 
     /*------------------------------*/
     /* conversion of URL */
@@ -72,25 +58,25 @@ namespace Kita
     QString convertURL( int mode, const KURL& url , QString& refstr );
 
     QString datToOfflaw( const KURL& datURL );
-    
-    
-    /*------------------------------*/    
+
+
+    /*------------------------------*/
     /* utilities */
     bool mkdir( const QString& path );
     QString unescape( const QString& str );
     uint datToSince( const KURL& datURL );
     int isEqual( const QChar *cdat, const QString& str );
     int stringToPositiveNum( const QChar *cdat, const unsigned int length );
-    
+
 
     /*------------------------------*/
     /* internal parsing funtions */
 
-    
+
     /* for MACHI BBS */
     void InitParseMachiBBS();
     QString ParseMachiBBSOneLine( const QString& inputLine, int& nextNum );
-    
+
     /* for JBBS */
     QString ParseJBBSOneLine( const QString& line, int& nextNum );
 
@@ -98,31 +84,24 @@ namespace Kita
     /* for Flash CGI/Mini Thread */
     QString ParseFlashCGIOneLine( const QString& line );
 
-    
+
     /* for 2ch */
-    void parseTITLEdat( int mode, DOM::HTMLDocument& hdoc, int num,
-			bool showMailAddress, const RESDAT& resdat,
-			DOM::Element &titlenode, QString& titletext );
-    void parseTITLEdatText( int mode, int num, bool showMailAddress,
-				   const RESDAT& resdat, QString& titletext );
-
-    void parseBODYdat( int mode, const QString &rawStr, DOM::HTMLDocument& hdoc,
-			      bool showAA, DOM::Element &bodynode, QString& bodytext );
-    void parseBODYdatText( int mode, const QString &rawStr, QString& bodytext );
-
-    QString parseSpecialChar( const QChar *cdat, unsigned int& pos );
-    void parseDateId( const QString& str, RESDAT& resdat );
     bool parseResDat( RESDAT& resdat, QString& subject );
+
+    void parseName( const QString& rawStr, RESDAT& resdat );
+    void parseDateId( const QString& rawStr, RESDAT& resdat );
+    void parseBody( const QString &rawStr, RESDAT& resdat );
+
     bool parseLink( const QChar *cdat, const unsigned int length,
-			   QString& linkstr, QString& linkurl, unsigned int& pos );
+                    QString& linkstr, QString& linkurl, unsigned int& pos );
     bool parseResAnchor( const QChar *cdat, const unsigned int length,
-				QString& linkstr, int* refNum, unsigned int& pos );
-    bool createResAnchor( int mode, const QString &rawStr, DOM::HTMLDocument& hdoc ,
-		     DOM::Element &bodynode, QString& bodytext,
-		     const QChar *chpt, unsigned int &i, unsigned int &index, QString& lineStr );
+                         QString& linkstr, int* refNum, unsigned int& pos );
+    bool createResAnchor( const QString &rawStr, RESDAT& resdat,
+                          const QChar *chpt, unsigned int &i, unsigned int &index );
+
+    void createTitleHTML( RESDAT& resdat, QString& titletext );
 
 
-    
     /*--------------------------------*/
     /* obsolete */
     QString datToBoard( const KURL& datURL );
