@@ -30,14 +30,7 @@ namespace Kita
 
         static KURL parseURLonly( const KURL& url ) { return Kita::getDatURL( url ); }
 
-        static QString qcpToUnicode( const QString& str ) { return Kita::qcpToUnicode( str ); }
-
         static QString utf8ToUnicode( const QString& str ) { return Kita::utf8ToUnicode( str ); }
-
-        static int stringToPositiveNum( const QChar *cdat, const unsigned int length )
-        {
-            return Kita::stringToPositiveNum( cdat, length );
-        }
     };
 
 }
