@@ -28,7 +28,7 @@ static const char *version = VERSION;
 static KCmdLineOptions options[] =
     {
         { "+[URL]", I18N_NOOP( "Document to open." ), 0 },
-        { "boardlist <boardlist>", I18N_NOOP( "board list's URL." ), "http://www.ff.iij4u.or.jp/~ch2/bbsmenu.html" },
+        { "boardlist <boardlist>", I18N_NOOP( "board list's URL." ), "http://menu.2ch.net/bbsmenu.html" },
         { 0, 0, 0 }
     };
 
