@@ -23,10 +23,14 @@ LoginPrefPage::LoginPrefPage( QWidget *parent )
     userIDLine->setText( KitaConfig::userID() );
     passwordLine->insert( KitaConfig::password() );
     autoLoginCheckBox->setChecked( KitaConfig::autoLogin() );
+    BeMailAddressLine->setText( KitaConfig::BeMailAddress() );
+    BeAuthCodeLine->insert( KitaConfig::BeAuthCode() );
 
     connect( userIDLine, SIGNAL( textChanged( const QString& ) ), SIGNAL( changed() ) );
     connect( passwordLine, SIGNAL( textChanged( const QString& ) ), SIGNAL( changed() ) );
     connect( autoLoginCheckBox, SIGNAL( toggled( bool ) ), SIGNAL( changed() ) );
+    connect( BeMailAddressLine, SIGNAL( textChanged( const QString& ) ), SIGNAL( changed() ) );
+    connect( BeAuthCodeLine, SIGNAL( textChanged( const QString& ) ), SIGNAL( changed() ) );
 }
 
 
@@ -38,6 +42,8 @@ void LoginPrefPage::apply()
     KitaConfig::setUserID( userIDLine->text() );
     KitaConfig::setPassword( passwordLine->password() );
     KitaConfig::setAutoLogin( autoLoginCheckBox->isChecked() );
+    KitaConfig::setBeMailAddress( BeMailAddressLine->text() );
+    KitaConfig::setBeAuthCode( BeAuthCodeLine->text() );
 }
 
 #include "loginprefpage.moc"
