@@ -303,8 +303,8 @@ FacePrefPage::FacePrefPage( QWidget* parent )
              SLOT( slotPopupFontButtonClicked() ) );
 
     Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
-    connect( this, SIGNAL( setFontOfHTMLPart() ),
-             signalCollection, SIGNAL( setFontOfHTMLPart() ) );
+    connect( this, SIGNAL( threadFaceChanged() ),
+             signalCollection, SIGNAL( threadFaceChanged() ) );
 
     updateButtons();
 
@@ -345,7 +345,7 @@ void FacePrefPage::apply()
     if ( m_threadFontchanged ) {
         QFont threadFont = threadFontButton->font();
         KitaConfig::setThreadFont( threadFont );
-        emit setFontOfHTMLPart(); /* to all HTMLPart */
+        emit threadFaceChanged();
     }
     m_threadFontchanged = FALSE;
 
@@ -357,7 +357,7 @@ void FacePrefPage::apply()
         KitaConfig::setThreadColor( threadColorButton->color() );
         KitaConfig::setThreadBackgroundColor( threadBackgroundColorButton->color() );
         // TODO: rename signal.
-        emit setFontOfHTMLPart();
+        emit threadFaceChanged();
     }
     m_threadColorChanged = FALSE;
     KitaConfig::setPopupColor( popupColorButton->color() );
