@@ -130,7 +130,7 @@ namespace Kita
 
     signals:
         void fontChanged( const QFont& );
-        void setFontOfHTMLPart();
+        void threadFaceChanged();
         void changed();
         void setStyleSheetOfHTMLPart();
     };
