@@ -630,7 +630,10 @@ void KitaDomTree::changeColorOfNumber( int num )
     m_coloredNum[ num ] = TRUE;
     DOM::Node node = m_titleElm[ num ];
     node = node.firstChild();
-    while ( node.nodeName().string() != "a" ) node = node.firstChild();  /* table tag is used. */
+    while ( ! node.isNull() && node.nodeName().string() != "a" ) {
+        node = node.firstChild();  /* table tag is used. */
+    }
+    if ( node.isNull() ) return;
 
     static_cast< DOM::HTMLElement> ( node ).setAttribute( "class", "coloredLink" );
 }
