@@ -121,7 +121,7 @@ public slots:
     /* rendering */
     void slotRedrawHTMLPart( const KURL& datURL, bool force );
     void slotRedrawAllHTMLPart( bool force );
-    void slotSetFontOfHTMLPart();
+    void slotSetFaceOfHTMLPart();
     void slotSetStyleSheetOfHTMLPart();
 
     /* cache */
