@@ -17,6 +17,7 @@
 #include "libkita/datmanager.h"
 #include "libkita/boardmanager.h"
 #include "libkita/kita-utf8.h"
+#include "libkita/kitaconfig.h"
 
 #include <kdebug.h>
 #include <kstdaccel.h>
@@ -325,6 +326,8 @@ void KitaThreadTabWidget::connectSignals()
              this, SLOT( slotUpdateThreadTab( const KURL& ) ) );
     connect( signalCollection, SIGNAL( closeThreadTab( const KURL& ) ),
              SLOT( slotCloseThreadTab( const KURL& ) ) );
+    connect( signalCollection, SIGNAL( threadFaceChanged() ),
+             SLOT( slotFontChanged() ) );
 }
 
 
@@ -380,7 +383,11 @@ void KitaThreadTabWidget::slotUpdateThreadTab( const KURL& url )
     }
 }
 
-
+void KitaThreadTabWidget::slotFontChanged()
+{
+    QFont font = KitaConfig::threadFont();
+    setFont( font );
+}
 
 /* protected */ /* virtual */
 void KitaThreadTabWidget::deleteWidget( QWidget* w )
