@@ -43,6 +43,9 @@
 #include <qcheckbox.h>
 #include <qlayout.h>
 
+#include <cstring>
+#include <cstdlib>
+
 /* result code */
 enum{
     K2ch_Unknown,
@@ -191,6 +194,10 @@ KitaWriteView::KitaWriteView( QWidget* parent, const char* name, const KURL& url
     for ( it = list.begin(); it != list.end(); ++it ) {
         faceCombo->insertItem( *it );
     }
+
+    cookie_type = NULL;
+    cookie_value = NULL;
+
 }
 
 
@@ -344,12 +351,48 @@ void KitaWriteView::slotRecieveData( KIO::Job*, const QByteArray& data )
     m_array.append( data.data() );
 }
 
+void KitaWriteView::find_cookie_typevalue( const char *response ){
+	char *str_cmp, *str;
+	static char *cookie_type_static = NULL;
+	static char *cookie_value_static = NULL;
+	cookie_type = cookie_value = NULL;
+
+	str_cmp = "<input type=hidden name=\"";
+	str = strstr(response, str_cmp);
+	if (str){
+		char *str2 = strstr(str, "\"");
+		char *str3 = NULL;
+		str2++;
+		if ((!cookie_type_static) || (!(strstr(str2, cookie_type_static)))){
+			free(cookie_type_static);
+			free(cookie_value_static);
+
+			cookie_type_static = strdup(str2);
+			str3 = strstr(cookie_type_static, "\"");
+			*str3 = 0;
+
+			str = str2;
+			str2 = strstr(str, "value=\"");
+			str = str2;
+			str2 = strstr(str, "\"");
+			str2++;
+			cookie_value_static = strdup(str2);
+			str3 = strstr(cookie_value_static, "\"");
+			*str3 = 0;
+		}
+	}
+	cookie_type = cookie_type_static;
+	cookie_value = cookie_value_static;
+}
+
+
 
 /* This slot is called when posting is done. */
 /* see also slotPostMessage()                */ /* private slot */
 void KitaWriteView::slotPostFinished( KIO::Job* )
 {
     QString response;
+    const char *response_ascii;
 
     // x-euc-jp & euc-jp
     if ( m_array.contains( "euc-jp" ) ) {
@@ -401,6 +444,9 @@ void KitaWriteView::slotPostFinished( KIO::Job* )
         /* eat cookie, then re-post message */
     case K2ch_Cookie:
 
+	response_ascii = (const char *) QString::fromLocal8Bit(response).utf8();
+	find_cookie_typevalue(response_ascii);
+
         if ( KMessageBox::questionYesNo( 0,
                                          QTextCodec::codecForName( "utf8" ) ->toUnicode( KITAUTF8_WRITECOOKIEMSG ),
                                          resultTitle( response ) )
@@ -509,7 +555,12 @@ QString KitaWriteView::setPostStr()
     ( ret += "&mail=" ) += KURL::encode_string( mailLine->text(), mib );
     ( ret += "&MESSAGE=" ) += KURL::encode_string( bodyText->text(), mib );
     ( ret += "&bbs=" ) += Kita::BoardManager::boardID( m_datURL );
-    ( ret += "&suka=pontan" );
+    if (cookie_type) {
+      ret += "&" ;
+      ret += cookie_type;
+      ret += "=";
+      ret += cookie_value;
+    }
 
     /* key */
     if ( m_mode == WRITEMODE_NORMAL ) ( ret += "&key=" ) += Kita::DatManager::threadID( m_datURL );
