@@ -45,6 +45,9 @@ class KitaWriteView : public KitaWriteDialogBase
 
     static QCp932Codec* m_cp932Codec;
 
+    char *cookie_type;
+    char *cookie_value;
+
 public:
 
     KitaWriteView( QWidget* parent, const char* name, const KURL& url, int mode, const QString& newThreadName = QString::null );
@@ -70,6 +73,7 @@ private slots:
     void slotRecieveData( KIO::Job*, const QByteArray& );
     void slotPostFinished( KIO::Job* );
     void slotCurrentChanged ( QWidget * w );
+    void find_cookie_typevalue( const char *response );
     bool slotBodyTextChanged();
 
 private:
